.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. Technical Note on Data Quality.

.. toctree::
    :maxdepth: 2
   
.. _TotalDepth-tech-data-quality:

***************************************************
Data Quality
***************************************************

TODO:
